@@ -208,22 +208,13 @@ def usePyFlinkEnv(parallelism: int = None, flinkHome: str = None) -> MLEnv:
     if flinkHome is not None:
         g_config["flink_home"] = flinkHome
 
-    if g_config["flink_home"] is None:
-        # Running using flink run ***.py
-        # Let PyFlink to launch gateway, and warn users to add jars to pyflink lib path
-        print("Warning: it seems you're running the script using 'flink run'. "
-              "In this case, you have to manually add alink jars to pyflink lib path.")
-        import pyflink
-        gateway = pyflink.java_gateway.get_gateway()
-        pyflink.java_gateway.import_flink_view(gateway)
-        set_java_gateway(gateway)
-    else:
-        # running using python ***.py
-        # PyAlink will launch gateway
-        import pyflink
-        gateway = get_java_gateway()
-        pyflink.java_gateway._gateway = gateway
-        pyflink.java_gateway.import_flink_view(gateway)
+    # Let PyFlink to launch gateway, and warn users to add jars to pyflink lib path
+    print("Warning: You're running the script with 'getMLEnv'. "
+          "You have to manually add Alink jars to PyFlink lib path to make the script work.")
+    import pyflink
+    gateway = pyflink.java_gateway.get_gateway()
+    pyflink.java_gateway.import_flink_view(gateway)
+    set_java_gateway(gateway)
 
     from pyflink.dataset import ExecutionEnvironment
     from pyflink.datastream import StreamExecutionEnvironment
